@@ -1062,18 +1062,24 @@ hdf_read_ndgs(NC *handle)
                         if (err_code != DFE_NONE)
                             HGOTO_ERROR(err_code, FAIL);
 
-                        /* get space for dimensions */
-                        dimsizes = malloc((uint32)rank * sizeof(int32));
+                        /* get space for dimensions, variable dimensions, and scale types */
+                        if (rank > 0) {
+                            dimsizes   = malloc((uint32)rank * sizeof(int32));
+                            vardims    = malloc((uint32)rank * sizeof(intn));
+                            scaletypes = malloc((uint32)rank * sizeof(int32));
+                        }
+                        else {
+                            /* when rank = 0, use rank = 1, assuming the data is scalar */
+                            dimsizes   = malloc(sizeof(int32));
+                            vardims    = malloc(sizeof(intn));
+                            scaletypes = malloc(sizeof(int32));
+                        }
                         if (dimsizes == NULL) {
                             HGOTO_ERROR(DFE_NOSPACE, FAIL);
                         }
-
-                        vardims = malloc((uint32)rank * sizeof(intn));
                         if (vardims == NULL) {
                             HGOTO_ERROR(DFE_NOSPACE, FAIL);
                         }
-
-                        scaletypes = malloc((uint32)rank * sizeof(int32));
                         if (scaletypes == NULL) {
                             HGOTO_ERROR(DFE_NOSPACE, FAIL);
                         }
